<?php
// If this file is called directly, abort.
if ( !defined( 'ABSPATH' ) ) {
    exit;
}
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://www.multidots.com/
 * @since      1.0.0
 *
 * @package    Eu_Cookie_Notice
 * @subpackage Eu_Cookie_Notice/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Eu_Cookie_Notice
 * @subpackage Eu_Cookie_Notice/admin
 * @author     Multidots <inquiry@multidots.in>
 */
class Eu_Cookie_Notice_Admin {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Eu_Cookie_Notice_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Eu_Cookie_Notice_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/eu-cookie-notice-admin.css', array('wp-color-picker', 'wp-jquery-ui-dialog'), $this->version, 'all');

        if (!empty($_GET['page']) && isset($_GET['page']) && $_GET['page'] == 'eu_cookie_notice') {
            wp_enqueue_style($this->plugin_name . '-ui', plugin_dir_url(__FILE__) . 'css/jquery-ui.css', array(), $this->version, 'all');
        }

        wp_enqueue_style('wp-pointer');
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Eu_Cookie_Notice_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Eu_Cookie_Notice_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        if (isset($_GET['page']) && !empty($_GET['page']) && ($_GET['page'] == "eu_cookie_notice")) {
            wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/eu-cookie-notice-admin.js', array('jquery', 'wp-color-picker', 'jquery-ui-tabs', 'jquery-ui-dialog'), $this->version, false);

            wp_localize_script('eu-cookie-notice', 'ajax_params', array(
                'ajax_url' => admin_url('admin-ajax.php'),
                'ajax_icon' => plugin_dir_url(__FILE__) . '/images/ajax-loader.gif'
            ));
            wp_enqueue_script('eu-cookie-notice');
            wp_enqueue_script('wp-pointer');
        }
    }

    public function custom_eu_cookie_notice_pointers_footer() {
        $admin_pointers = custom_eu_cookie_notice_pointers_admin_pointers();
        ?>
        <script type="text/javascript">
            /* <![CDATA[ */
            (function($) {
        <?php
        foreach ($admin_pointers as $pointer => $array) {
            if ($array['active']) {
                ?>
                        $('<?php echo $array['anchor_id']; ?>').pointer({
                            content: '<?php echo $array['content']; ?>',
                            position: {
                                edge: '<?php echo $array['edge']; ?>',
                                align: '<?php echo $array['align']; ?>'
                            },
                            close: function() {
                                $.post(ajaxurl, {
                                    pointer: '<?php echo $pointer; ?>',
                                    action: 'dismiss-wp-pointer'
                                });
                            }
                        }).pointer('open');
                <?php
            }
        }
        ?>
            })(jQuery);
            /* ]]> */
        </script>
        <?php
    }

    // Function For Welcome page to plugin 
    public function welcome_eu_cookie_notice_screen_do_activation_redirect() {

        if (!get_transient('_welcome_screen_eu_cookie_notice_activation_redirect_data')) {
            return;
        }

        // Delete the redirect transient
        delete_transient('_welcome_screen_eu_cookie_notice_activation_redirect_data');

        // if activating from network, or bulk
        if (is_network_admin() || isset($_GET['activate-multi'])) {
            return;
        }
        // Redirect to extra cost welcome  page
        wp_safe_redirect(add_query_arg(array('page' => 'eu_cookie_notice_welcome_page&tab=about'), admin_url('index.php')));
    }

    public function welcome_pages_screen_eu_cookie_notice() {
        add_dashboard_page(
                'Eu Cookie Notice Dashboard', 'Eu Cookie Notice Dashboard', 'read', 'eu_cookie_notice_welcome_page', array(&$this, 'welcome_screen_content_eu_cookie_notice')
        );
    }

    public function welcome_screen_content_eu_cookie_notice() {
        ?>

        <div class="wrap about-wrap">
            <h1 style="font-size: 2.1em;"><?php printf(__('Welcome to Eu Cookie Notice', 'eu-cookie-notice')); ?></h1>

            <div class="about-text woocommerce-about-text">
                <?php
                $message = '';
                printf(__('%s Cookie Notice plugin allows you to simple inform users that your site uses cookies and to comply with the EU cookie law regulations.', 'eu-cookie-notice'), $message, $this->version);
                ?>
                <img class="version_logo_img" src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'images/eucnotice.png'); ?>">
            </div>

            <?php
            $setting_tabs_wc = apply_filters('eu_cookie_notice_setting_tab', array("about" => "Overview", "other_plugins" => "Checkout our other plugins"));
            $current_tab_wc = (isset($_GET['tab'])) ? sanitize_text_field(wp_unslash($_GET['tab'])) : 'general';
            $aboutpage = isset($_GET['page'])
            ?>
            <h2 id="woo-extra-cost-tab-wrapper" class="nav-tab-wrapper">
                <?php
                foreach ($setting_tabs_wc as $name => $label)
                    echo '<a  href="' . esc_url(home_url('wp-admin/index.php?page=eu_cookie_notice_welcome_page&tab=' . $name)) . '" class="nav-tab ' . ( $current_tab_wc == $name ? 'nav-tab-active' : '' ) . '">' . esc_html($label) . '</a>';
                ?>
            </h2>

            <?php
            foreach ($setting_tabs_wc as $setting_tabkey_wc => $setting_tabvalue) {
                switch ($setting_tabkey_wc) {
                    case $current_tab_wc:
                        do_action('eu_cookie_notice_' . $current_tab_wc);
                        break;
                }
            }
            ?>
            <hr />
            <div class="return-to-dashboard">
                <a href="<?php echo esc_url(home_url('/wp-admin/admin.php?page=eu_cookie_notice')); ?>"><?php _e('Go to Eu Cookie Notice Settings', 'eu-cookie-notice'); ?></a>
            </div>
        </div>
        <?php
    }

    /**
     * About tab content of Add social share button about
     *
     */
    public function eu_cookie_notice_about() {
        //do_action('my_own');
        $current_user = wp_get_current_user();
        ?>
        <div class="changelog">
            </br>
            <style type="text/css">
                p.eu_cookie_notice_overview {max-width: 100% !important;margin-left: auto;margin-right: auto;font-size: 15px;line-height: 1.5;}
                .eu_cookie_notice_ul ul li {margin-left: 3%;list-style: initial;line-height: 23px;}
            </style>  
            <div class="changelog about-integrations">
                <div class="wc-feature feature-section col three-col">
                    <div>

                        <p class="eu_cookie_notice_overview"><?php _e('Cookie Notice plugin is a simple, configurable notice that appears on sticky top, Sticky Bottom and Popup of the page. Easily closed by the user.you can add script in header and footer as per your choice.', 'eu-cookie-notice'); ?></p>

                        <p class="eu_cookie_notice_overview"><strong><?php _e('Plugin Functionality:', 'eu-cookie-notice'); ?></strong></p> 
                        <div class="eu_cookie_notice_ul">
                            <ul>
                                <li><?php _e('Customize the cookie message', 'eu-cookie-notice'); ?></li>
                                <li><?php _e('Redirect users to specified page for more cookie information', 'eu-cookie-notice'); ?></li>
                                <li><?php _e('Set cookie expiry', 'eu-cookie-notice'); ?></li>
                                <li><?php _e('Custom cookie Message (sticky top, Sticky Bottom and Popup)', 'eu-cookie-notice'); ?></li>
                                <li><?php _e('Link to more info page', 'eu-cookie-notice'); ?></li>
                                <li><?php _e('Option to accept cookies on scroll', 'eu-cookie-notice'); ?></li>
                                <li><?php _e('Option to refuse functional cookies', 'eu-cookie-notice'); ?></li>
                                <li><?php _e('Select the position of the cookie message box', 'eu-cookie-notice'); ?></li>
                                <li><?php _e('Animate the message box after cookie is accepted', 'eu-cookie-notice'); ?></li>
                                <li><?php _e('Select bottons style from None, WordPress and Bootstrap', 'eu-cookie-notice'); ?></li>
                                <li><?php _e('Set the text and bar background colors', 'eu-cookie-notice'); ?></li>
                            </ul>
                        </div>

                    </div>

                </div>
            </div>
        </div>

        <?php
    }

    public function adjust_the_wp_menu_eu_cookie_notice() {
        remove_submenu_page('index.php', 'eu_cookie_notice_welcome_page');
    }

    /**
     * function for add eu cookie admin menu
     *
     */
    public function cookie_warning_custom_admin_menu() {
        /**
         * add new admin menu
         */
        add_menu_page(EUCN_PLUGIN_MENU_TITLE, __(EUCN_PLUGIN_MENU_NAME, 'eu-cookie-notice'), 'manage_options', EUCN_PLUGIN_MENU_SLUG, 'eucn_custom_admin_setting_options');

        /**
         * function for cookie notice settings
         */
        function eucn_custom_admin_setting_options() {
            global $post, $wpdb;
            ?>
            <div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>main_container">
                <div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>title"><h2><?php echo __(EUCN_PLUGIN_NAME, 'eu-cookie-notice'); ?></h2></div>
                <div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>notice"></div>
                <div id="tabscokkie">
                    <form id="cw_plugin_form_id" method="post" action="<?php echo esc_url(get_admin_url().'admin-post.php'); ?>" enctype="multipart/form-data" novalidate="novalidate">
                        <?php wp_nonce_field(basename(__FILE__), 'eu_cookie_setting_nonce'); ?>
                        <input type='hidden' name='action' value='submit-form-cookie' />
                        <input type='hidden' name='action-which' value='add' />
                        <ul>
                            <li><a href="#settings"><?php echo __(EUCN_PLIGIN_SETTING_TAB, 'eu-cookie-notice'); ?></a></li>
                            <li><a href="#buttons"><?php echo __(EUCN_PLIGIN_BUTTONS_TAB, 'eu-cookie-notice'); ?></a></li>
                            <li><a href="#advancesettings"><?php echo __(EUCN_PLIGIN_ADD_SETTING_TAB, 'eu-cookie-notice'); ?></a></li>
                        </ul>

                        <div id="settings">
                            <div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>sub_contain">
                                <h2><?php echo __(EUCN_PLUGIN_CONFIGURATION_TEXT, 'eu-cookie-notice'); ?></h2>
                                <?php
                                $getcwoptionarray = get_option('cookie_warning_option');
                                $getcwoptionarray = maybe_unserialize($getcwoptionarray);
                                ?>
                                <table class="form-table">
                                    <tbody>
                                        <tr>
                                            <th><?php echo __('Enable Cookie Bar', 'eu-cookie-notice') ?></th>
                                            <td>
                                                <div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>row">
                                                    <?php
                                                    if ($getcwoptionarray != '') {
                                                        if (isset($getcwoptionarray['cw_cookie_bar_enabled']) && $getcwoptionarray['cw_cookie_bar_enabled'] != '' && !empty($getcwoptionarray['cw_cookie_bar_enabled'])) {
                                                            ?>
                                                            <label><input <?php
                                                                if (isset($getcwoptionarray['cw_cookie_bar_enabled']) && $getcwoptionarray['cw_cookie_bar_enabled'] == 'yes') {
                                                                    echo 'checked';
                                                                }
                                                                ?> type="radio" checked name="cw_cookie_bar_enabled" value="yes"><?php echo __('On', 'eu-cookie-notice'); ?></label>
                                                            <label><input <?php
                                                                if (isset($getcwoptionarray['cw_cookie_bar_enabled']) && $getcwoptionarray['cw_cookie_bar_enabled'] == 'no') {
                                                                    echo 'checked';
                                                                }
                                                                ?> type="radio" name="cw_cookie_bar_enabled" value="no"><?php echo __('Off', 'eu-cookie-notice'); ?></label><?php } else {
                                                                ?>
                                                            <label><input type="radio" checked name="cw_cookie_bar_enabled" value="yes"><?php echo __('On', 'eu-cookie-notice'); ?></label>
                                                            <label><input type="radio" name="cw_cookie_bar_enabled" value="no"><?php echo __('Off', 'eu-cookie-notice'); ?></label><?php
                                                        }
                                                    } else {
                                                        ?>
                                                        <label><input type="radio" checked name="cw_cookie_bar_enabled" value="yes"><?php echo __('On', 'eu-cookie-notice'); ?></label>
                                                        <label><input type="radio" name="cw_cookie_bar_enabled" value="no"><?php echo __('Off', 'eu-cookie-notice'); ?></label><?php }
                                                    ?>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th><?php echo __(EUCN_PLUGIN_CONFIGURATION_MSG, 'eu-cookie-notice'); ?></th>
                                            <td><div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>row"><textarea name="cw_display_message"><?php echo isset($getcwoptionarray['cw_message']) ? wp_kses_post($getcwoptionarray['cw_message']) : ""; ?></textarea><p><?php echo __(EUCN_PLIGIN_MESSAGE_TOOLTIP, 'eu-cookie-notice'); ?></p></div></td>
                                        </tr>
                                        <tr>
                                            <th><?php echo __(EUCN_PLUGIN_ON_SCROLL_TXT, 'eu-cookie-notice'); ?></th>
                                            <td>
                                                <div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>row">
                                                    <input type="checkbox" <?php
                                                    if (isset($getcwoptionarray['cw_refuse_on_scroll']) && $getcwoptionarray['cw_refuse_on_scroll'] == '1') {
                                                        echo"checked";
                                                    }
                                                    ?> value="<?php echo isset($getcwoptionarray['cw_refuse_on_scroll']) ? intval($getcwoptionarray['cw_refuse_on_scroll']) : '0'; ?>" name="cw_refuse_on_scroll_btn" id="cw_refuse_on_scroll_btn" ><?php echo __(EUCN_PLUGIN_ON_SCROLL_OPTION_TEXT, 'eu-cookie-notice'); ?>
                                                </div>
                                                <div <?php
                                                if (isset($getcwoptionarray['cw_refuse_on_scroll']) && $getcwoptionarray['cw_refuse_on_scroll'] == '1') {
                                                    echo 'style="display:block"';
                                                } else {
                                                    echo 'style="display:none"';
                                                }
                                                ?> class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>onscroll_contain">
                                                    <input type="text" value="<?php echo !empty($getcwoptionarray['cw_refuse_on_scroll_amount']) ? intval($getcwoptionarray['cw_refuse_on_scroll_amount']) : '100'; ?>" name="cw_on_scroll_amount"> px
                                                    <p><?php echo __(EUCN_PLIGIN_REFUSE_SCROLL_TOOLTIP, 'eu-cookie-notice'); ?></p>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th><?php echo __(EUCN_PLUGIN_COOKIE_EXPIRY_TEXT, 'eu-cookie-notice'); ?></th>
                                            <td>
                                                <select name="cw_cookie_expiry_time">
                                                    <option <?php
                                                    if (isset($getcwoptionarray['cw_cookie_expiry_time']) && esc_attr($getcwoptionarray['cw_cookie_expiry_time']) == '1day') {
                                                        echo 'selected';
                                                    }
                                                    ?> value="1day"><?php esc_html_e('1 day', 'eu-cookie-notice'); ?></option>
                                                    <option <?php
                                                    if (isset($getcwoptionarray['cw_cookie_expiry_time']) && esc_attr($getcwoptionarray['cw_cookie_expiry_time']) == '1week') {
                                                        echo 'selected';
                                                    }
                                                    ?> value="1week"><?php esc_html_e('1 week', 'eu-cookie-notice'); ?></option>
                                                    <option <?php
                                                    if (isset($getcwoptionarray['cw_cookie_expiry_time']) && esc_attr($getcwoptionarray['cw_cookie_expiry_time']) == '1month') {
                                                        echo 'selected';
                                                    }
                                                    ?> value="1month"><?php esc_html_e('1 month', 'eu-cookie-notice'); ?></option> 
                                                    <option <?php
                                                    if (isset($getcwoptionarray['cw_cookie_expiry_time']) && esc_attr($getcwoptionarray['cw_cookie_expiry_time']) == '3months') {
                                                        echo 'selected';
                                                    }
                                                    ?> value="3months"><?php esc_html_e('3 months', 'eu-cookie-notice'); ?></option>
                                                    <option <?php
                                                    if (isset($getcwoptionarray['cw_cookie_expiry_time']) && esc_attr($getcwoptionarray['cw_cookie_expiry_time']) == '6months') {
                                                        echo 'selected';
                                                    }
                                                    ?> value="6months"><?php esc_html_e('6 months', 'eu-cookie-notice'); ?></option>
                                                    <option <?php
                                                    if (isset($getcwoptionarray['cw_cookie_expiry_time']) && esc_attr($getcwoptionarray['cw_cookie_expiry_time']) == '1year') {
                                                        echo 'selected';
                                                    }
                                                    ?> value="1year"><?php esc_html_e('1 year', 'eu-cookie-notice'); ?></option>
                                                    <option <?php
                                                    if (isset($getcwoptionarray['cw_cookie_expiry_time']) && esc_attr($getcwoptionarray['cw_cookie_expiry_time']) == 'infinity') {
                                                        echo 'selected';
                                                    }
                                                    ?> value="infinity"><?php esc_html_e('infinity', 'eu-cookie-notice'); ?></option>
                                                </select>
                                                <p><?php echo __(EUCN_PLIGIN_COOKIE_EXPIRE_TOOLTIP, 'eu-cookie-notice'); ?></p>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th><?php echo __(EUCN_PLUGIN_SCRIPT_PLACEMENT_TEXT, 'eu-cookie-notice'); ?></th>
                                            <td>
                                                <?php
                                                if ($getcwoptionarray != '') {
                                                    if (isset($getcwoptionarray['cw_cookie_script_placement']) && $getcwoptionarray['cw_cookie_script_placement'] != '' && !empty($getcwoptionarray['cw_cookie_script_placement'])) {
                                                        ?>
                                                        <label><input <?php
                                                            if (isset($getcwoptionarray['cw_cookie_script_placement']) && esc_attr($getcwoptionarray['cw_cookie_script_placement']) == 'header') {
                                                                echo 'checked';
                                                            }
                                                            ?> type="radio" checked name="cw_script_placement" value="header"><?php echo __('Header', 'eu-cookie-notice'); ?></label>
                                                        <label><input <?php
                                                            if (isset($getcwoptionarray['cw_cookie_script_placement']) && esc_attr($getcwoptionarray['cw_cookie_script_placement']) == 'footer') {
                                                                echo 'checked';
                                                            }
                                                            ?> type="radio" name="cw_script_placement" value="footer"><?php echo __('Footer', 'eu-cookie-notice'); ?></label><?php } else {
                                                            ?>
                                                        <label><input type="radio" checked name="cw_script_placement" value="header"><?php echo __('Header', 'eu-cookie-notice'); ?></label>
                                                        <label><input type="radio" name="cw_script_placement" value="footer"><?php echo __('Footer', 'eu-cookie-notice'); ?></label><?php
                                                    }
                                                } else {
                                                    ?>
                                                    <label><input type="radio" checked name="cw_script_placement" value="header"><?php echo __('Header', 'eu-cookie-notice'); ?></label>
                                                    <label><input type="radio" name="cw_script_placement" value="footer"><?php echo __('Footer', 'eu-cookie-notice'); ?></label><?php }
                                                ?>
                                                <p><?php echo __('Select where the plugin scripts should be placed.', 'eu-cookie-notice'); ?></p>
                                            </td>
                                        </tr>
                                        <tr style="display:none;">
                                            <th><?php echo __(EUCN_PLUGIN_DEACTIVATION_TEXT, 'eu-cookie-notice'); ?></th>
                                            <td><input type="checkbox" <?php
                                                if (isset($getcwoptionarray['cw_deactivation_option']) && esc_attr($getcwoptionarray['cw_deactivation_option']) == '1') {
                                                    echo'checked';
                                                }
                                                ?> value="<?php echo isset($getcwoptionarray['cw_deactivation_option']) ? esc_attr($getcwoptionarray['cw_deactivation_option']) : '0'; ?>" name="cw_deactivation_option" id="cw_deactivation_option"></td>
                                        </tr>
                                        <tr>
                                            <th><?php echo __(EUCN_PLUGIN_MSG_POSITION, 'eu-cookie-notice'); ?></th>
                                            <td>
                                                <?php
                                                if ($getcwoptionarray != '') {
                                                    if (isset($getcwoptionarray['cw_message_position']) && $getcwoptionarray['cw_message_position'] != '' && !empty($getcwoptionarray['cw_message_position'])) {
                                                        ?>
                                                        <label><input type="radio" <?php
                                                            if (isset($getcwoptionarray['cw_message_position']) && esc_attr($getcwoptionarray['cw_message_position']) == 'top') {
                                                                echo 'checked';
                                                            }
                                                            ?> name="cw_msg_position" class="cw_msg_position" value="top"><?php echo __('Sticky Top', 'eu-cookie-notice'); ?> <img class="msg_position" alt="sticky top" src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'images/top__image.jpg'); ?>" /></label>
                                                        <label><input type="radio" <?php
                                                            if (isset($getcwoptionarray['cw_message_position']) && esc_attr($getcwoptionarray['cw_message_position']) == 'bottom') {
                                                                echo 'checked';
                                                            }
                                                            ?> name="cw_msg_position" class="cw_msg_position" value="bottom"><?php echo __('Sticky Bottom', 'eu-cookie-notice'); ?>  <img class="msg_position" alt="sticky bottom" src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'images/bottom__image.jpg'); ?>" /></label>
                                                        <label><input type="radio" <?php
                                                            if (isset($getcwoptionarray['cw_message_position']) && esc_attr($getcwoptionarray['cw_message_position']) == 'fancybox') {
                                                                echo 'checked';
                                                            }
                                                            ?> name="cw_msg_position" class="cw_msg_position" value="fancybox"><?php echo __('Popup', 'eu-cookie-notice'); ?> <img class="msg_position" alt="popup" src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'images/popup__image.jpg'); ?>" /></label><?php } else {
                                                            ?>
                                                        <label><input type="radio" checked name="cw_msg_position" class="cw_msg_position" value="top"><?php echo __('Sticky Top', 'eu-cookie-notice'); ?><img class="msg_position" alt="sticky top" src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'images/top__image.jpg'); ?>" /></label>
                                                        <label><input type="radio" name="cw_msg_position" class="cw_msg_position" value="bottom"><?php echo __('Sticky Bottom', 'eu-cookie-notice'); ?> <img class="msg_position" alt="sticky bottom" src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'images/bottom__image.jpg'); ?>" /></label>
                                                        <label><input type="radio" name="cw_msg_position" class="cw_msg_position" value="fancybox"><?php echo __('Popup', 'eu-cookie-notice'); ?> <img class="msg_position" alt="popup" src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'images/popup__image.jpg'); ?>" /></label><?php
                                                    }
                                                } else {
                                                    ?>
                                                    <label><input type="radio" checked name="cw_msg_position" class="cw_msg_position" value="top"><?php echo __('Sticky Top', 'eu-cookie-notice'); ?><img class="msg_position" alt="sticky top" src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'images/top__image.jpg'); ?>" /></label>
                                                    <label><input type="radio" name="cw_msg_position" class="cw_msg_position" value="bottom"><?php echo __('Sticky Bottom', 'eu-cookie-notice'); ?> <img class="msg_position" alt="sticky bottom" src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'images/bottom__image.jpg'); ?>" /></label>
                                                    <label><input type="radio" name="cw_msg_position" class="cw_msg_position" value="fancybox"><?php echo __('Popup', 'eu-cookie-notice'); ?> <img class="msg_position" alt="popup" src="<?php echo esc_url(plugin_dir_url(__FILE__) . 'images/popup__image.jpg'); ?>" /></label><?php }
                                                ?>
                                                <p><?php echo __(EUCN_PLIGIN_MSG_POSITION_TOOLTIP, 'eu-cookie-notice'); ?></p>
                                            </td>
                                        </tr>
                                        <?php
                                        $displayoption = '';
                                        if (isset($getcwoptionarray['cw_message_position']) && !empty($getcwoptionarray['cw_message_position']) & $getcwoptionarray['cw_message_position'] == 'fancybox') {
                                            $displayoption = ' style="display:none"';
                                        } else {
                                            $displayoption = '';
                                        }
                                        ?>
                                        <tr <?php echo $displayoption; ?> class="cw_cookie_animation_enable">
                                            <th ><?php echo __(EUCN_PLUGIN_MSG_ANIMATION, 'eu-cookie-notice'); ?></th>
                                            <td >
                                                <?php
                                                if ($getcwoptionarray != '') {
                                                    if (isset($getcwoptionarray['cw_message_animation']) && $getcwoptionarray['cw_message_animation'] != '' && !empty($getcwoptionarray['cw_message_animation'])) {
                                                        ?>
                                                        <label><input type="radio"  <?php
                                                            if (isset($getcwoptionarray['cw_message_animation']) && $getcwoptionarray['cw_message_animation'] == 'none') {
                                                                echo 'checked';
                                                            }
                                                            ?> name="cw_msg_animation" class="cw_msg_animation" value="none"><?php echo __('None', 'eu-cookie-notice'); ?></label>
                                                        <label><input type="radio"  <?php
                                                            if (isset($getcwoptionarray['cw_message_animation']) && $getcwoptionarray['cw_message_animation'] == 'fade') {
                                                                echo 'checked';
                                                            }
                                                            ?> name="cw_msg_animation" class="cw_msg_animation" value="fade"><?php echo __('Fade', 'eu-cookie-notice'); ?></label>
                                                        <label><input type="radio"  <?php
                                                            if (isset($getcwoptionarray['cw_message_animation']) && $getcwoptionarray['cw_message_animation'] == 'slide') {
                                                                echo 'checked';
                                                            }
                                                            ?> name="cw_msg_animation" class="cw_msg_animation" value="slide"><?php echo __('Slide', 'eu-cookie-notice'); ?></label>
                                                                  <?php } else { ?>
                                                        <label><input type="radio"  checked name="cw_msg_animation" class="cw_msg_animation" value="none"><?php echo __('None', 'eu-cookie-notice'); ?></label>
                                                        <label><input type="radio"  name="cw_msg_animation" class="cw_msg_animation" value="fade"><?php echo __('Fade', 'eu-cookie-notice'); ?></label>
                                                        <label><input type="radio"  name="cw_msg_animation" class="cw_msg_animation" value="slide"><?php echo __('Slide', 'eu-cookie-notice'); ?></label><?php
                                                    }
                                                } else {
                                                    ?>
                                                    <label><input type="radio"  checked name="cw_msg_animation" class="cw_msg_animation" value="none"><?php echo __('None', 'eu-cookie-notice'); ?></label>
                                                    <label><input type="radio"  name="cw_msg_animation" class="cw_msg_animation" value="fade"><?php echo __('Fade', 'eu-cookie-notice'); ?></label>
                                                    <label><input type="radio"  name="cw_msg_animation" class="cw_msg_animation" value="slide"><?php echo __('Slide', 'eu-cookie-notice'); ?></label><?php }
                                                ?>
                                                <p><?php echo __(EUCN_PLIGIN_MSG_ANIMATION_TOOLTIP, 'eu-cookie-notice'); ?></p>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th><?php echo __(EUCN_PLUGIN_MSG_COLOR_EFFECT_TXT, 'eu-cookie-notice'); ?></th>
                                            <td>
                                                <div class="<?php echo EUCN_HTML_CLASS_PREFIX; ?>color_main">
                                                    <p><?php echo __('Message box Text color', 'eu-cookie-notice'); ?></p>
                                                    <input type="text" name="cw_box_text_color" value="<?php echo !empty($getcwoptionarray['cw_box_text_color']) ? esc_attr($getcwoptionarray['cw_box_text_color']) : '#FFFFFF'; ?>" class="cw_txt_color_effect">
                                                </div>
                                                <div class="<?php echo EUCN_HTML_CLASS_PREFIX; ?>color_main">
                                                    <p><?php echo __('Message box Bakground color', 'eu-cookie-notice'); ?></p>
                                                    <input type="text" name="cw_box_bg_color" value="<?php echo !empty($getcwoptionarray['cw_box_bg_color']) ? esc_attr($getcwoptionarray['cw_box_bg_color']) : '#000000'; ?>" class="cw_box_color_effect">
                                                </div>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th><?php echo __('Auto-hide cookie bar after delay?', 'eu-cookie-notice'); ?></th>
                                            <td>
                                                <div class="<?php echo EUCN_HTML_CLASS_PREFIX; ?>row">
                                                    <?php
                                                    if ($getcwoptionarray != '') {
                                                        if (isset($getcwoptionarray['cw_cookie_auto_hide']) && $getcwoptionarray['cw_cookie_auto_hide'] != '' && !empty($getcwoptionarray['cw_cookie_auto_hide'])) {
                                                            ?>
                                                            <label><input <?php
                                                                if (isset($getcwoptionarray['cw_cookie_auto_hide']) && $getcwoptionarray['cw_cookie_auto_hide'] == 'yes') {
                                                                    echo 'checked';
                                                                }
                                                                ?> type="radio" checked name="cw_cookie_auto_hide" value="yes"><?php echo __('On', 'eu-cookie-notice'); ?></label>
                                                            <label><input <?php
                                                                if (isset($getcwoptionarray['cw_cookie_auto_hide']) && $getcwoptionarray['cw_cookie_auto_hide'] == 'no') {
                                                                    echo 'checked';
                                                                }
                                                                ?> type="radio" name="cw_cookie_auto_hide" value="no"><?php echo __('Off', 'eu-cookie-notice'); ?></label><?php } else {
                                                                ?>
                                                            <label><input type="radio" checked name="cw_cookie_auto_hide" value="yes"><?php echo __('On', 'eu-cookie-notice'); ?></label>
                                                            <label><input type="radio" name="cw_cookie_auto_hide" value="no"><?php echo __('Off', 'eu-cookie-notice'); ?></label><?php
                                                        }
                                                    } else {
                                                        ?>
                                                        <label><input type="radio" checked name="cw_cookie_auto_hide" value="yes"><?php echo __('On', 'eu-cookie-notice'); ?></label>
                                                        <label><input type="radio" name="cw_cookie_auto_hide" value="no"><?php echo __('Off', 'eu-cookie-notice'); ?></label><?php }
                                                    ?>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th><?php echo __('Milliseconds until hidden', 'eu-cookie-notice'); ?></th>
                                            <td>
                                                <div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>row">
                                                    <?php
                                                    if ($getcwoptionarray != '') {
                                                        if (isset($getcwoptionarray['cw_cookie_auto_hide_seconds']) && $getcwoptionarray['cw_cookie_auto_hide_seconds'] != '' && !empty($getcwoptionarray['cw_cookie_auto_hide_seconds'])) {
                                                            ?>
                                                            <input type="text" value="<?php echo !empty($getcwoptionarray['cw_cookie_auto_hide_seconds']) ? esc_attr($getcwoptionarray['cw_cookie_auto_hide_seconds']) : '5000'; ?>" name="cw_cookie_auto_hide_seconds"><?php } else {
                                                            ?>
                                                            <input type="text" value="5000" name="cw_cookie_auto_hide_seconds"><?php
                                                        }
                                                    } else {
                                                        ?>
                                                        <input type="text" value="5000" name="cw_cookie_auto_hide_seconds"><?php }
                                                    ?>
                                                </div>
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                        <!--html for buttons tab settings-->
                        <div id="buttons">
                            <div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>sub_contain">
                                <table class="form-table">
                                    <tbody>
                                        <tr>
                                            <th><?php echo __(EUCN_PLUGIN_BUTTON_TXT, 'eu-cookie-notice'); ?></th>
                                            <td><div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>row"><input type="text" value="<?php echo isset($getcwoptionarray['cw_yes_btn']) ? $getcwoptionarray['cw_yes_btn'] : "ok"; ?>" name="cw_display_btn_txt"><p><?php echo __(EUCN_PLIGIN_BUTTON_OK_TOOLTIP, 'eu-cookie-notice'); ?></p></div></td>
                                        </tr>
                                        <tr>
                                            <th><?php echo __(EUCN_PLUGIN_MORE_INFO_LINK, 'eu-cookie-notice'); ?></th>
                                            <td>
                                                <div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>row">
                                                    <input type="checkbox" <?php
                                                    if (isset($getcwoptionarray['cw_more_info_link']) && $getcwoptionarray['cw_more_info_link'] != '' && $getcwoptionarray['cw_more_info_link'] == '1') {
                                                        echo "checked";
                                                    }
                                                    ?> value="<?php echo isset($getcwoptionarray['cw_more_info_link']) ? esc_attr($getcwoptionarray['cw_more_info_link']) : "0"; ?>" name="cw_more_info_links" id="cw_more_info_links" ><?php echo __(EUCN_PLUGIN_MORE_LINK_OPTION); ?>
                                                </div>
                                                <div  <?php
                                                if (isset($getcwoptionarray['cw_more_info_link']) && $getcwoptionarray['cw_more_info_link'] != '' && $getcwoptionarray['cw_more_info_link'] == '1') {
                                                    echo 'style="display:block"';
                                                } else {
                                                    echo 'style="display:none"';
                                                }
                                                ?> class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>more_info">
                                                    <input type="text" value="<?php echo !empty($getcwoptionarray['cw_more_link_txt']) ? esc_attr($getcwoptionarray['cw_more_link_txt']) : 'Read more'; ?>" name="cw_more_links_text">
                                                    <p><?php _e('The text of the more info button.', 'eu-cookie-notice'); ?></p>
                                                    <?php if (!empty($getcwoptionarray['cw_more_info_link']) && $getcwoptionarray['cw_more_info_link'] != '' && $getcwoptionarray['cw_more_info_link'] == '1') { ?> 
                                                        <label><input type="radio" <?php
                                                            if (isset($getcwoptionarray['cw_page_attribte']) && $getcwoptionarray['cw_page_attribte'] == 'custom') {
                                                                echo 'checked';
                                                            }
                                                            ?> name="cw_page_link_attribute" value="custom" class="cw_page_custom_link" ><?php _e('Custom Link', 'eu-cookie-notice'); ?></label>
                                                        <label><input type="radio" <?php
                                                            if (isset($getcwoptionarray['cw_page_attribte']) && $getcwoptionarray['cw_page_attribte'] == 'pages') {
                                                                echo 'checked';
                                                            }
                                                            ?> name="cw_page_link_attribute" value="pages" class="cw_page_custom_link"><?php _e('Page Link', 'eu-cookie-notice'); ?></label>
                                                                  <?php } else { ?>
                                                        <label><input type="radio" checked name="cw_page_link_attribute" value="custom" class="cw_page_custom_link" ><?php _e('Custom Link', 'eu-cookie-notice'); ?></label>
                                                        <label><input type="radio" name="cw_page_link_attribute" value="pages" class="cw_page_custom_link"><?php _e('Page Link', 'eu-cookie-notice'); ?></label>
                                                    <?php } ?>
                                                    <p><?php echo __(EUCN_PLIGIN_LINK_CUSTOM_PAGE_TOOLTIP, 'eu-cookie-notice'); ?></p>
                                                    <div <?php
                                                    if (isset($getcwoptionarray['cw_page_attribte']) && $getcwoptionarray['cw_page_attribte'] == 'custom') {
                                                        echo 'style="display:block"';
                                                    } else {
                                                        echo 'style="display:none"';
                                                    }
                                                    ?> class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>custom_link_option">
                                                        <input type="text" name="cw_custom_page_link" value="<?php echo isset($getcwoptionarray['cw_page_links']) ? $getcwoptionarray['cw_page_links'] : ''; ?>">
                                                        <p><?php echo __(EUCN_PLIGIN_LINK_URL_TOOLTIP, 'eu-cookie-notice'); ?></p>
                                                    </div>
                                                    <div <?php
                                                    if (isset($getcwoptionarray['cw_page_attribte']) && $getcwoptionarray['cw_page_attribte'] == 'pages') {
                                                        echo 'style="display:block"';
                                                    } else {
                                                        echo 'style="display:none"';
                                                    }
                                                    ?> class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>page_link_option">
                                                        <select name="cw_select_page_link">
                                                            <option value="">-- <?php _e('Select Page', 'eu-cookie-notice'); ?> --</option>
                                                            <?php
                                                            $args = array(
                                                                'posts_per_page' => -1,
                                                                'post_type' => 'page',
                                                                'orderby' => 'title',
                                                                'order' => 'ASC',
                                                                'post_status' => 'publish',
                                                            );
                                                            $posts_array = get_posts($args);
                                                            if (isset($posts_array) && !empty($posts_array) && $posts_array != '') {
                                                                foreach ($posts_array as $key => $value) {
                                                                    ?>
                                                                    <?php if (isset($getcwoptionarray['cw_page_select_links']) && $getcwoptionarray['cw_page_select_links'] != '' && !empty($getcwoptionarray['cw_page_select_links'])) { ?>
                                                                        <option <?php
                                                                        if (isset($getcwoptionarray['cw_page_select_links']) && $getcwoptionarray['cw_page_select_links'] == $value->ID) {
                                                                            echo "selected";
                                                                        }
                                                                        ?> value="<?php echo esc_attr($value->ID); ?>"><?php echo esc_attr($value->post_title); ?></option>
                                                                        <?php } else { ?>
                                                                        <option value="<?php echo esc_attr($value->ID); ?>"><?php echo esc_attr($value->post_title); ?></option>
                                                                    <?php } ?>
                                                                    <?php
                                                                }
                                                            }
                                                            ?>
                                                        </select>
                                                        <p><?php echo __(EUCN_PLIGIN_LINK_SITE_PAGE_TOOLTIP, 'eu-cookie-notice'); ?></p>
                                                    </div>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th><?php echo __(EUCN_PLUGIN_MORE_LINK_TARGET, 'eu-cookie-notice'); ?></th>
                                            <td><div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>row">
                                                    <select name="cw_target_attribute">
                                                        <option <?php
                                                        if (isset($getcwoptionarray['cw_page_link_target']) && $getcwoptionarray['cw_page_link_target'] != '' && $getcwoptionarray['cw_page_link_target'] == '_blank') {
                                                            echo 'selected';
                                                        }
                                                        ?> value="_blank"><?php _e('_blank', 'eu-cookie-notice'); ?></option>
                                                        <option <?php
                                                        if (isset($getcwoptionarray['cw_page_link_target']) && $getcwoptionarray['cw_page_link_target'] != '' && $getcwoptionarray['cw_page_link_target'] == '_self') {
                                                            echo 'selected';
                                                        }
                                                        ?> value="_self"><?php _e('_self', 'eu-cookie-notice'); ?></option>
                                                    </select>
                                                    <p><?php echo __(EUCN_PLIGIN_LINK_TARGET_TOOLTIP, 'eu-cookie-notice'); ?></p>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th><?php echo __(EUCN_PLUGIN_REFUSE_BTN_TEXT, 'eu-cookie-notice'); ?></th>
                                            <td>
                                                <div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>row">
                                                    <input type="checkbox" <?php
                                                    if (isset($getcwoptionarray['cw_refuse_btn_chk']) && $getcwoptionarray['cw_refuse_btn_chk'] == '1') {
                                                        echo"checked";
                                                    }
                                                    ?> value="<?php echo isset($getcwoptionarray['cw_refuse_btn_chk']) ? esc_attr($getcwoptionarray['cw_refuse_btn_chk']) : '0'; ?>" name="cw_refuse_chk_btn" id="cw_refuse_chk_btn" ><?php echo __(EUCN_PLUGIN_REFUSE_OPTION_TEXT, 'eu-cookie-notice'); ?> <?php _e('(Give to the user the possibility to refuse third party non functional cookies.)', 'eu-cookie-notice'); ?>
                                                </div>
                                                <div <?php
                                                if (isset($getcwoptionarray['cw_refuse_btn_chk']) && $getcwoptionarray['cw_refuse_btn_chk'] == '1') {
                                                    echo 'style="display:block"';
                                                } else {
                                                    echo 'style="display:none"';
                                                }
                                                ?> class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>refuse_contain">
                                                    <input type="text" value="<?php echo!empty($getcwoptionarray['cw_refuse_btn_text']) ? esc_attr($getcwoptionarray['cw_refuse_btn_text']) : 'no'; ?>" name="cw_refuse_btn_txt" id="cw_refuse_btn_txt">
                                                    <p><?php echo __(EUCN_PLIGIN_REFUSE_BTN_TOOLTIP, 'eu-cookie-notice'); ?></p>
                                                    <textarea name="cw_refuse_additional_script" id="cw_refuse_additional_script"><?php echo !empty($getcwoptionarray['cw_refuse_additional_script']) ? esc_attr($getcwoptionarray['cw_refuse_additional_script']) : ''; ?></textarea>
                                                    <p><?php echo __(EUCN_PLIGIN_REFUSE_SCRIPT_TOOLTIP, 'eu-cookie-notice'); ?></p>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th><?php echo __(EUCN_PLUGIN_BUTTON_STYLE_TXT, 'eu-cookie-notice'); ?></th>
                                            <td>
                                                <?php if (!empty($getcwoptionarray['cw_button_style']) && $getcwoptionarray['cw_button_style'] != '') { ?> 
                                                    <label><input type="radio" <?php
                                                        if ($getcwoptionarray['cw_button_style'] == 'none') {
                                                            echo 'checked';
                                                        }
                                                        ?>  name="cw_msg_btn_styles" class="cw_msg_btn_style" value="none"><?php _e('None', 'eu-cookie-notice'); ?></label>
                                                    <label><input type="radio" <?php
                                                        if ($getcwoptionarray['cw_button_style'] == 'wordpress') {
                                                            echo 'checked';
                                                        }
                                                        ?> name="cw_msg_btn_styles" class="cw_msg_btn_style" value="wordpress"><?php _e('WordPress', 'eu-cookie-notice'); ?></label>
                                                    <label><input type="radio" <?php
                                                        if ($getcwoptionarray['cw_button_style'] == 'bootstrap') {
                                                            echo 'checked';
                                                        }
                                                        ?> name="cw_msg_btn_styles" class="cw_msg_btn_style" value="bootstrap"><?php _e('Bootstrap', 'eu-cookie-notice'); ?></label>
                                                              <?php } else { ?> 
                                                    <label><input type="radio"  checked name="cw_msg_btn_styles" class="cw_msg_btn_style" value="none"><?php _e('None', 'eu-cookie-notice'); ?></label>
                                                    <label><input type="radio"  name="cw_msg_btn_styles" class="cw_msg_btn_style" value="wordpress"><?php _e('WordPress', 'eu-cookie-notice'); ?></label>
                                                    <label><input type="radio"  name="cw_msg_btn_styles" class="cw_msg_btn_style" value="bootstrap"><?php _e('Bootstrap', 'eu-cookie-notice'); ?></label>
                                                <?php } ?> 
                                                <P><?php echo __(EUCN_PLIGIN_BTN_STYLE_TOOLTIP, 'eu-cookie-notice'); ?></P>
                                                <?php
                                                if ($getcwoptionarray != '') {
                                                    if ($getcwoptionarray['cw_button_style'] != '' && !empty($getcwoptionarray['cw_button_style'])) {
                                                        ?>
                                                        <div <?php
                                                        if ($getcwoptionarray['cw_button_style'] == 'none') {
                                                            echo'style="display:block"';
                                                        } else {
                                                            echo'style="display:none"';
                                                        }
                                                        ?> class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>custom_button_style">
                                                            <p><?php _e('Button Text color', 'eu-cookie-notice'); ?></p>
                                                            <input type="text" name="cw_button_text_color" value="<?php echo !empty($getcwoptionarray['cw_button_text_color']) ? esc_attr($getcwoptionarray['cw_button_text_color']) : '#CCCCCC'; ?>" class="cw_txt_color_effect">
                                                            <p><?php _e('Button Bakground color', 'eu-cookie-notice'); ?></p>
                                                            <input type="text" name="cw_button_bg_color" value="<?php echo !empty($getcwoptionarray['cw_button_bg_color']) ? esc_attr($getcwoptionarray['cw_button_bg_color']) : '#000000'; ?>" class="cw_txt_color_effect">
                                                        </div><?php } else {
                                                        ?>
                                                        <div class="<?php echo EUCN_HTML_CLASS_PREFIX; ?>custom_button_style">
                                                            <p><?php _e('Button Text color', 'eu-cookie-notice'); ?></p>
                                                            <input type="text" name="cw_button_text_color" value="<?php echo !empty($getcwoptionarray['cw_button_text_color']) ? esc_attr($getcwoptionarray['cw_button_text_color']) : '#CCCCCC'; ?>" class="cw_txt_color_effect">
                                                            <p><?php _e('Button Bakground color', 'eu-cookie-notice'); ?></p>
                                                            <input type="text" name="cw_button_bg_color" value="<?php echo !empty($getcwoptionarray['cw_button_bg_color']) ? esc_attr($getcwoptionarray['cw_button_bg_color']) : '#000000'; ?>" class="cw_txt_color_effect">
                                                        </div><?php
                                                    }
                                                } else {
                                                    ?>
                                                    <div class="<?php echo EUCN_HTML_CLASS_PREFIX; ?>custom_button_style">
                                                        <p><?php _e('Button Text color', 'eu-cookie-notice'); ?></p>
                                                        <input type="text" name="cw_button_text_color" value="<?php echo !empty($getcwoptionarray['cw_button_text_color']) ? esc_attr($getcwoptionarray['cw_button_text_color']) : '#CCCCCC'; ?>" class="cw_txt_color_effect">
                                                        <p><?php _e('Button Bakground color', 'eu-cookie-notice'); ?></p>
                                                        <input type="text" name="cw_button_bg_color" value="<?php echo !empty($getcwoptionarray['cw_button_bg_color']) ? esc_attr($getcwoptionarray['cw_button_bg_color']) : '#000000'; ?>" class="cw_txt_color_effect">
                                                    </div><?php }
                                                ?>
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                        <div id="advancesettings">
                            <div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>sub_contain">
                                <table class="form-table">
                                    <tbody>
                                        <tr>
                                            <td>
                                                <div class="<?php echo esc_attr(EUCN_HTML_CLASS_PREFIX); ?>row">
                                                    <p><?php echo __(EUCN_PLUGIN_ADD_SETTING_CONTENT, 'eu-cookie-notice'); ?></p>
                                                    <input type="button" value="<?php echo __(EUCN_PLIGIN_RESET_BUTTON, 'eu-cookie-notice'); ?>" name="cw_reset_options" class="button button-primary" id="cw_reset_settings">
                                                    <p><?php echo __(EUCN_PLUGIN_ADD_SETT_WARN_MSG, 'eu-cookie-notice'); ?></p>
                                                </div>
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                        <p class="submit"><input type="submit" value="<?php echo __(EUCN_PLIGIN_SAVE_BUTTON, 'eu-cookie-notice'); ?>" name="cw_scve_option" class="button button-primary" ></p>
                    </form>
                </div>
            </div>
            <?php
        }

    }

    /**
     * function for add or update plugin settings
     *
     */
    function cw_add_update_options() {
        global $post, $wpdb;

        //get action
        $getformaction = isset($_POST['action']) ? sanitize_text_field(wp_unslash($_POST['action'])) : '';

        //get form action
        $getaction = isset($_POST['action-which']) ? sanitize_text_field(wp_unslash($_POST['action-which'])) : '';

        //check form action not null
        if (!empty($getaction) && $getaction == 'add' && $getformaction == 'submit-form-cookie') {
            // verify nonce
            if (!isset($_POST['eu_cookie_setting_nonce']) || !wp_verify_nonce($_POST['eu_cookie_setting_nonce'], basename(__FILE__))) {
                die('Failed security check');
            }
            //get plugin settings option
            $getcwdisplaymessage = isset($_POST['cw_display_message']) ? stripslashes(sanitize_text_field(wp_unslash($_POST['cw_display_message']))) : '';
            $getcwenabled = isset($_POST['cw_cookie_bar_enabled']) ? sanitize_text_field(wp_unslash($_POST['cw_cookie_bar_enabled'])) : '';
            $getcwautoHide = isset($_POST['cw_cookie_auto_hide']) ? sanitize_text_field(wp_unslash($_POST['cw_cookie_auto_hide'])) : '';
            $getcwautoHideSeconds = isset($_POST['cw_cookie_auto_hide_seconds']) ? sanitize_text_field(wp_unslash($_POST['cw_cookie_auto_hide_seconds'])) : '';
            $getcwdisplaybtntxt = trim(sanitize_text_field(wp_unslash($_POST['cw_display_btn_txt'])));
            $getcwdisplaybtntxt = !empty($getcwdisplaybtntxt) ? sanitize_text_field(wp_unslash($getcwdisplaybtntxt)) : 'Ok';
            $getcwmoreinfolinks = isset($_POST['cw_more_info_links']) ? sanitize_text_field(wp_unslash($_POST['cw_more_info_links'])) : '';
            $getcwpagelinks = '';
            $getcwmorelinkstext = '';
            $getcwpagselectelinks = '';
            $getcwpagelinkattribute = '';

            if (!empty($getcwmoreinfolinks) && $getcwmoreinfolinks != '' && $getcwmoreinfolinks == '1') {

                $getcwmorelinkstext = isset($_POST['cw_more_links_text']) ? sanitize_text_field(wp_unslash($_POST['cw_more_links_text'])) : '';
                $getcwpagelinkattribute = isset($_POST['cw_page_link_attribute']) ? sanitize_text_field(wp_unslash($_POST['cw_page_link_attribute'])) : '';

                if ($getcwpagelinkattribute != '' && !empty($getcwpagelinkattribute) && $getcwpagelinkattribute == 'custom') {
                    $getcwpagelinks = isset($_POST['cw_custom_page_link']) ? sanitize_text_field(wp_unslash($_POST['cw_custom_page_link'])) : '';
                }

                if ($getcwpagelinkattribute != '' && !empty($getcwpagelinkattribute) && $getcwpagelinkattribute == 'pages') {
                    $getcwpagselectelinks = isset($_POST['cw_select_page_link']) ? sanitize_text_field(wp_unslash($_POST['cw_select_page_link'])) : '';
                }
            }

            $getlinktaget = isset($_POST['cw_target_attribute']) ? sanitize_text_field(wp_unslash($_POST['cw_target_attribute'])) : '';
            $getrefusebtnchk = isset($_POST['cw_refuse_chk_btn']) ? sanitize_text_field(wp_unslash($_POST['cw_refuse_chk_btn'])) : '';

            $getrefusebtntext = '';
            $getrefuseadditionalscript = '';

            if (!empty($getrefusebtnchk) && $getrefusebtnchk != '' && $getrefusebtnchk == '1') {
                $getrefusebtntext = isset($_POST['cw_refuse_btn_txt']) ? sanitize_text_field(wp_unslash($_POST['cw_refuse_btn_txt'])) : '';
                $getrefuseadditionalscript = isset($_POST['cw_refuse_additional_script']) ? stripslashes(sanitize_text_field(wp_unslash($_POST['cw_refuse_additional_script']))) : '';
            }

            $getrefuseonscroll = isset($_POST['cw_refuse_on_scroll_btn']) ? sanitize_text_field(wp_unslash($_POST['cw_refuse_on_scroll_btn'])) : '';

            $getrefuseonscrollamount = '';

            if ($getrefuseonscroll != '' && !empty($getrefuseonscroll) && $getrefuseonscroll == '1') {
                $getrefuseonscrollamount = isset($_POST['cw_on_scroll_amount']) ? sanitize_text_field(wp_unslash($_POST['cw_on_scroll_amount'])) : '';
            }

            $getcookieexpiretime = isset($_POST['cw_cookie_expiry_time']) ? sanitize_text_field(wp_unslash($_POST['cw_cookie_expiry_time'])) : '';
            $getscriptplacement = isset($_POST['cw_script_placement']) ? sanitize_text_field(wp_unslash($_POST['cw_script_placement'])) : '';
            $getdeactivationoption = isset($_POST['cw_deactivation_option']) ? sanitize_text_field(wp_unslash($_POST['cw_deactivation_option'])) : '';
            $getmessageboxposition = isset($_POST['cw_msg_position']) ? sanitize_text_field(wp_unslash($_POST['cw_msg_position'])) : '';
            $getmessageboxanimation = isset($_POST['cw_msg_animation']) ? sanitize_text_field(wp_unslash($_POST['cw_msg_animation'])) : '';
            $getbuttonstyle = isset($_POST['cw_msg_btn_styles']) ? sanitize_text_field(wp_unslash($_POST['cw_msg_btn_styles'])) : '';

            $getbuttontextcolor = '';
            $getbuttonbgcolor = '';
            if (!empty($getbuttonstyle) && $getbuttonstyle != '' && $getbuttonstyle == 'none') {
                $getbuttontextcolor = isset($_POST['cw_button_text_color']) ? sanitize_text_field(wp_unslash($_POST['cw_button_text_color'])) : '';
                $getbuttonbgcolor = isset($_POST['cw_button_bg_color']) ? sanitize_text_field(wp_unslash($_POST['cw_button_bg_color'])) : '';
            }

            $getmsgboxtextcolor = isset($_POST['cw_box_text_color']) ? sanitize_text_field(wp_unslash($_POST['cw_box_text_color'])) : '';
            $getmsgboxbgcolor = isset($_POST['cw_box_bg_color']) ? sanitize_text_field(wp_unslash($_POST['cw_box_bg_color'])) : '';

            /**
             * create plugin settings array
             */
            $cwoptionarry = array();
            $cwoptionarry['cw_cookie_bar_enabled'] = $getcwenabled;
            $cwoptionarry['cw_cookie_auto_hide'] = $getcwautoHide;
            $cwoptionarry['cw_cookie_auto_hide_seconds'] = $getcwautoHideSeconds;
            $cwoptionarry['cw_message'] = $getcwdisplaymessage;
            $cwoptionarry['cw_yes_btn'] = $getcwdisplaybtntxt;
            $cwoptionarry['cw_more_info_link'] = $getcwmoreinfolinks;
            $cwoptionarry['cw_more_link_txt'] = $getcwmorelinkstext;
            $cwoptionarry['cw_page_attribte'] = $getcwpagelinkattribute;
            $cwoptionarry['cw_page_links'] = $getcwpagelinks;
            $cwoptionarry['cw_page_select_links'] = $getcwpagselectelinks;
            $cwoptionarry['cw_page_link_target'] = $getlinktaget;
            $cwoptionarry['cw_refuse_btn_chk'] = $getrefusebtnchk;
            $cwoptionarry['cw_refuse_btn_text'] = $getrefusebtntext;
            $cwoptionarry['cw_refuse_additional_script'] = $getrefuseadditionalscript;
            $cwoptionarry['cw_refuse_on_scroll'] = $getrefuseonscroll;
            $cwoptionarry['cw_refuse_on_scroll_amount'] = $getrefuseonscrollamount;
            $cwoptionarry['cw_cookie_expiry_time'] = $getcookieexpiretime;
            $cwoptionarry['cw_cookie_script_placement'] = $getscriptplacement;
            $cwoptionarry['cw_deactivation_option'] = $getdeactivationoption;
            $cwoptionarry['cw_message_position'] = $getmessageboxposition;
            $cwoptionarry['cw_message_animation'] = $getmessageboxanimation;
            $cwoptionarry['cw_button_style'] = $getbuttonstyle;
            $cwoptionarry['cw_button_text_color'] = $getbuttontextcolor;
            $cwoptionarry['cw_button_bg_color'] = $getbuttonbgcolor;
            $cwoptionarry['cw_box_text_color'] = $getmsgboxtextcolor;
            $cwoptionarry['cw_box_bg_color'] = $getmsgboxbgcolor;

            /**
             * plugin settings array encoded
             */
            $cwoptionarry = maybe_serialize($cwoptionarry);

            /**
             * update plugin option
             */
            update_option('cookie_warning_option', $cwoptionarry);

            /**
             * redirect to plugin settings tab 
             */
            wp_safe_redirect(esc_url(site_url("/wp-admin/admin.php?page=" . EUCN_PLUGIN_MENU_SLUG)));
            exit();
        }
    }

      /**
     * function for plugin all settings reset.
     *
     */
    function cw_reset_settings() {
        global $wpdb;

        /**
         * update all settings as null
         */
        update_option('cookie_warning_option', '');

        die();
    }

}

function custom_eu_cookie_notice_pointers_admin_pointers() {

    $dismissed = explode(',', (string) get_user_meta(get_current_user_id(), 'dismissed_wp_pointers', true));
    $version = '1_0_6'; // replace all periods in 1.0 with an underscore
    $prefix = 'custom_eu_cookie_notice_pointers' . $version . '_';

    $new_pointer_content = '<h3>' . __('Welcome to Eu Cookie Notice', 'eu-cookie-notice') . '</h3>';
    $new_pointer_content .= '<p>' . __('Cookie Notice plugin is a simple, configurable notice that appears on sticky top, Sticky Bottom and Popup of the page. Easily closed by the user.you can add script in header and footer as per your choice.', 'eu-cookie-notice') . '</p>';

    return array(
        $prefix . 'eu_cookie_notice_view' => array(
            'content' => $new_pointer_content,
            'anchor_id' => '#adminmenu',
            'edge' => 'left',
            'align' => 'left',
            'active' => (!in_array($prefix . 'eu_cookie_notice_view', $dismissed) )
        )
    );
}
